use utf8;

package SemanticWeb::Schema::InsertAction;

# ABSTRACT: The act of adding at a specific location in an ordered collection.

use Moo;

extends qw/ SemanticWeb::Schema::AddAction /;


use MooX::JSON_LD 'InsertAction';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v0.0.3';


has to_location => (
    is        => 'rw',
    predicate => 1,
    json_ld   => 'toLocation',
);





1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::InsertAction - The act of adding at a specific location in an ordered collection.

=head1 VERSION

version v0.0.3

=head1 DESCRIPTION

The act of adding at a specific location in an ordered collection.

=head1 ATTRIBUTES

=head2 C<to_location>

C<toLocation>

A sub property of location. The final location of the object or the agent
after the action.

A to_location should be one of the following types:

=over

=item C<InstanceOf['SemanticWeb::Schema::Place']>

=back

=head1 SEE ALSO

L<SemanticWeb::Schema::AddAction>

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
